{ config, lib, self, ... }:

{
  imports = [
    self.inputs.disko.nixosModules.disko
    ./hardware-configuration.nix
    ./disko-config.nix
    ../desktop.nix
  ];

  nixpkgs = {
    hostPlatform = "x86_64-linux";
    config = {
      allowUnfree = true;
      nvidia.acceptLicense = true;
    };
  };

  boot.loader = {
    systemd-boot.enable = true;
    efi.canTouchEfiVariables = true;
  };

  networking.hostId = "cf791898";

  # nvidia 470 driver doesn't work with Wayland
  services = {
    xserver = {
      displayManager.gdm.wayland = lib.mkForce false;
      videoDrivers = [ "nvidia" ];
    };
    displayManager = {
      defaultSession = if config.modules.desktop.kde.enable then "plasmax11" else "gnome-xorg";
      sddm.wayland.enable = lib.mkForce false;
    };
  };

  # Workaround for label rendering bug in GTK4 with nvidia 470 driver
  environment.sessionVariables.GSK_RENDERER = "gl";

  modules = {
    desktop = {
      browsers = {
        firefox.enable = true;
      };
      media.recording = {
        audio.enable = true;
      };
    };
    dev = {
      node.enable = true;
    };
    editors = {
      neovim.enable = true;
    };
    security = {
      gpg.enable = true;
      pass.enable = true;
    };
    shell = {
      git.enable = true;
      zsh.enable = true;
    };
  };

  system.stateVersion = "22.11";
}
